@@ -90,7 +90,12 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
-		return r3sponse.ResponseObject(response)
+		if response["succcess"] in [True, "True", "true"]:
+			try:  del response["message"]
+			try:  del response["error"]
+			return r3sponse.success_response(response["message"], response)
+		else:
+			return r3sponse.error_response(response["error"])
 	def get(self, group=None, id=None):
 		encoded = urllib.parse.urlencode({
 			"group":group,
@@ -105,7 +110,12 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
-		return r3sponse.ResponseObject(response)
+		if response["succcess"] in [True, "True", "true"]:
+			try:  del response["message"]
+			try:  del response["error"]
+			return r3sponse.success_response(response["message"], response)
+		else:
+			return r3sponse.error_response(response["error"])
 	def app(self):
 		app = flask.Flask(__name__)
 		cli = sys.modules['flask.cli']
